<?php


namespace Schaffen\Core\Person\Managers;


use Freelabois\LaravelQuickstart\Extendables\ManipulationManager;
use Illuminate\Support\Facades\App;
use Illuminate\Support\Facades\DB;
use Schaffen\Core\Person\Models\Person;
use Schaffen\Core\Person\Repositories\PersonRepository;

class PersonManager extends ManipulationManager
{
    protected $validation = [
        self::CREATE => [],
        self::EDIT => []
    ];

    /**
     * @var PersonRepository
     */
    protected $repository;

    public function __construct(PersonRepository $repository)
    {
        $this->repository = $repository;
    }

   /**
    * @param $values
    * @param int|null $id
    * @param array $relations
    * @return Person
    * @throws \Throwable
    */
    public function storeOrUpdate($values, int $id = null, $relations = []): Person
    {
        return DB::transaction(function () use ($values, $id, $relations) {
            /** @var Person $person */
            $person = parent::storeOrUpdate($values, $id, $relations);
            if ($id === null) {
                /** @var AddressManager $addressManager */
                $addressManager = app()->make(AddressManager::class);
                $address = $values['address'];
                $address['pee_padrao'] = 1;
                $address['pee_fk_pes_codigo'] = $person->pes_codigo;
                $addressManager->storeOrUpdate($address);

                /** @var ContactManager $contactManager */
                $contactManager = app()->make(ContactManager::class);
                $contact = $values['contact'];
                $contact['peco_padrao'] = 1;
                $contact['peco_fk_pes_codigo'] = $person->pes_codigo;
                $contactManager->storeOrUpdate($contact);
                $person->load(['address', 'contact']);
            }
            return $person;
        });
    }

}
